@@ -21,7 +21,7 @@ from enum import Enum
 
 
 if typing.TYPE_CHECKING:
-    from typing import Dict, List, Optional, Union
+    from typing import Dict, List, Optional, Union, Any
     from datetime import datetime
 
 
@@ -39,7 +39,7 @@ class SessionEndedErrorType(Enum):
     ENDPOINT_TIMEOUT = "ENDPOINT_TIMEOUT"
 
     def to_dict(self):
-        # type: () -> Dict[str, object]
+        # type: () -> Dict[str, Any]
         """Returns the model properties as a dict"""
         result = {self.name: self.value}
         return result
@@ -55,7 +55,7 @@ class SessionEndedErrorType(Enum):
         return self.to_str()
 
     def __eq__(self, other):
-        # type: (object) -> bool
+        # type: (Any) -> bool
         """Returns true if both objects are equal"""
         if not isinstance(other, SessionEndedErrorType):
             return False
@@ -63,6 +63,6 @@ class SessionEndedErrorType(Enum):
         return self.__dict__ == other.__dict__
 
     def __ne__(self, other):
-        # type: (object) -> bool
+        # type: (Any) -> bool
         """Returns true if both objects are not equal"""
         return not self == other
